@@ -1,10 +1,10 @@
 import os
 import pygame
 
-from .main import Pygame, Image, Sound, Music
+from . import main, image
 
 class Element:
-    def __init__(self, image : Image, parent : Pygame, centerPosition = [0, 0], speed = [1, 1]):
+    def __init__(self, image : image.Image, parent : main.Pygame, centerPosition = [0, 0], speed = [1, 1]):
         
         os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 
